@@ -1,6 +1,6 @@
 covparms <-
 function(object) {
-  if(class(object) != "glmssn") return("Not a glmssn object")
+  if(class(object)[[1]] != "glmssn") return("Not a glmssn object")
   summary(object)$covariance.parameter.estimates
 }
 
