@@ -247,10 +247,12 @@ splitPredictions <- function(ssn, predpointsID, chunksof, by, subset, new.id)
                                         pid.vec <- append(pid.vec, tmp.pid)
                                         rm(tmp.pid)
 
-					##write to file
+					##write subset of prediction points to file
 					subsetted.spatialStructure <- sp::SpatialPointsDataFrame(coords = subsetted.coords,
-                                                  data = subsetted.data, proj4string = ssn@predpoints@SSNPoints[[i]]@proj4string)
-					maptools::writeSpatialShape(subsetted.spatialStructure, new.id)
+                                                   data = subsetted.data, proj4string = ssn@predpoints@SSNPoints[[i]]@proj4string)
+
+					##maptools::writeSpatialShape(subsetted.spatialStructure, new.id)
+                                        writeOGR(subsetted.spatialStructure, ".", new.id, verbose = FALSE, driver = "ESRI Shapefile")
 
 					#and alter the existing object
 					new.index <- length(ssn@predpoints@ID) + 1
@@ -298,7 +300,8 @@ splitPredictions <- function(ssn, predpointsID, chunksof, by, subset, new.id)
 
 				subsetted.spatialStructure <- sp::SpatialPointsDataFrame(coords = subsetted.coords,
                                           data = subsetted.data, proj4string = ssn@predpoints@SSNPoints[[i]]@proj4string)
-				maptools::writeSpatialShape(subsetted.spatialStructure, new.id)
+			  	##maptools::writeSpatialShape(subsetted.spatialStructure, new.id)
+                                writeOGR(subsetted.spatialStructure, ".", new.id, verbose = FALSE, driver = "ESRI Shapefile")
 
 				#and alter the existing object
 				new.index <- length(ssn@predpoints@ID) + 1
@@ -356,7 +359,8 @@ splitPredictions <- function(ssn, predpointsID, chunksof, by, subset, new.id)
 					#write to file
 					subsetted.spatialStructure <- sp::SpatialPointsDataFrame(coords = subsetted.coords,
                                             data = subsetted.data, proj4string = ssn@predpoints@SSNPoints[[i]]@proj4string)
-					maptools::writeSpatialShape(subsetted.spatialStructure, new.id)
+					##maptools::writeSpatialShape(subsetted.spatialStructure, new.id)
+                                        writeOGR(subsetted.spatialStructure, ".", new.id, verbose = FALSE, driver = "ESRI Shapefile")
 
 					#and alter the existing object
 					new.index <- length(ssn@predpoints@ID) + 1
